@@ -19,14 +19,6 @@ package org.apache.maven.archiver;
  * under the License.
  */
 
-import java.io.File;
-import java.io.IOException;
-import java.util.ArrayList;
-import java.util.Collections;
-import java.util.List;
-import java.util.Map;
-import java.util.Properties;
-import java.util.Set;
 import org.apache.maven.artifact.Artifact;
 import org.apache.maven.artifact.DependencyResolutionRequiredException;
 import org.apache.maven.execution.MavenSession;
@@ -43,11 +35,20 @@ import org.codehaus.plexus.interpolation.PrefixedPropertiesValueSource;
 import org.codehaus.plexus.interpolation.RecursionInterceptor;
 import org.codehaus.plexus.interpolation.StringSearchInterpolator;
 import org.codehaus.plexus.interpolation.ValueSource;
-import org.codehaus.plexus.util.StringUtils;
+import org.apache.maven.shared.utils.StringUtils;
+
+import java.io.File;
+import java.io.IOException;
+import java.util.ArrayList;
+import java.util.Collections;
+import java.util.List;
+import java.util.Map;
+import java.util.Properties;
+import java.util.Set;
 
 /**
  * @author <a href="evenisse@apache.org">Emmanuel Venisse</a>
- * @version $Revision: 1235294 $ $Date: 2012-01-24 16:20:06 +0100 (Tue, 24 Jan 2012) $
+ * @version $Revision: 1634380 $ $Date: 2014-10-26 20:01:23 +0100 (Sun, 26 Oct 2014) $
  */
 public class MavenArchiver
 {
@@ -84,14 +85,16 @@ public class MavenArchiver
      * Return a pre-configured manifest
      *
      * @param project the project
-     * @param config the configuration to use
+     * @param config  the configuration to use
+     * @return a manifest, clients are recommended to use java.util.jar.Manifest datatype.
+     * @throws org.apache.maven.artifact.DependencyResolutionRequiredException
+     *          .
+     * @throws org.codehaus.plexus.archiver.jar.ManifestException
+     *          .
      * @todo Add user attributes list and user groups list
      * @deprecated
-     * @return a manifest, clients are recommended to use java.util.jar.Manifest datatype.
-     * @throws org.apache.maven.artifact.DependencyResolutionRequiredException .
-     * @throws org.codehaus.plexus.archiver.jar.ManifestException .
      */
-    @SuppressWarnings( "UnusedDeclaration" )
+    @SuppressWarnings ("UnusedDeclaration")
     public Manifest getManifest( MavenProject project, MavenArchiveConfiguration config )
         throws ManifestException, DependencyResolutionRequiredException
     {
@@ -102,8 +105,9 @@ public class MavenArchiver
         throws ManifestException, DependencyResolutionRequiredException
     {
         boolean hasManifestEntries = !config.isManifestEntriesEmpty();
-        @SuppressWarnings( "unchecked" )
-        Map<String, String> entries = hasManifestEntries ? config.getManifestEntries() : Collections.EMPTY_MAP;
+        Map<String, String> entries =
+            hasManifestEntries ? config.getManifestEntries() : Collections.<String, String>emptyMap();
+
         Manifest manifest = getManifest( session, project, config.getManifest(), entries );
 
         // any custom manifest entries in the archive configuration manifest?
@@ -162,7 +166,6 @@ public class MavenArchiver
      *
      * @todo Add user attributes list and user groups list
      */
-    @SuppressWarnings( { "JavaDoc", "UnusedDeclaration" } )
     public Manifest getManifest( MavenProject project, ManifestConfiguration config )
         throws ManifestException, DependencyResolutionRequiredException
     {
@@ -195,7 +198,7 @@ public class MavenArchiver
         }
         else
         {
-            // if the value is empty we have create an entry with an empty string 
+            // if the value is empty we have create an entry with an empty string
             // to prevent null print in the manifest file
             Manifest.Attribute attr = new Manifest.Attribute( key, "" );
             manifest.addConfiguredAttribute( attr );
@@ -218,8 +221,7 @@ public class MavenArchiver
         {
             StringBuilder classpath = new StringBuilder();
 
-            @SuppressWarnings( "unchecked" )
-            List<String> artifacts = project.getRuntimeClasspathElements();
+            @SuppressWarnings ("unchecked") List<String> artifacts = project.getRuntimeClasspathElements();
             String classpathPrefix = config.getClasspathPrefix();
             String layoutType = config.getClasspathLayoutType();
             String layout = config.getCustomClasspathLayout();
@@ -231,8 +233,8 @@ public class MavenArchiver
                 File f = new File( artifactFile );
                 if ( f.getAbsoluteFile().isFile() )
                 {
-                    @SuppressWarnings( "unchecked" )
-                    Artifact artifact = findArtifactWithFile( project.getArtifacts(), f );
+                    @SuppressWarnings ("unchecked") Artifact artifact =
+                        findArtifactWithFile( project.getArtifacts(), f );
 
                     if ( classpath.length() > 0 )
                     {
@@ -381,6 +383,11 @@ public class MavenArchiver
             {
                 addManifestAttribute( m, entries, "Implementation-Vendor", project.getOrganization().getName() );
             }
+
+            if ( project.getUrl() != null )
+            {
+                addManifestAttribute( m, entries, "Implementation-URL", project.getUrl() );
+            }
         }
 
         String mainClass = config.getMainClass();
@@ -394,7 +401,7 @@ public class MavenArchiver
         {
             // TODO: this is only for applets - should we distinguish them as a packaging?
             StringBuilder extensionsList = new StringBuilder();
-            @SuppressWarnings( "unchecked" ) Set<Artifact> artifacts = (Set<Artifact>)project.getArtifacts();
+            @SuppressWarnings ("unchecked") Set<Artifact> artifacts = (Set<Artifact>) project.getArtifacts();
 
             for ( Artifact artifact : artifacts )
             {
@@ -465,7 +472,6 @@ public class MavenArchiver
         }
     }
 
-    @SuppressWarnings( "UnusedDeclaration" )
     public JarArchiver getArchiver()
     {
         return archiver;
@@ -484,7 +490,7 @@ public class MavenArchiver
     /**
      * @deprecated
      */
-    @SuppressWarnings( "JavaDoc" )
+    @SuppressWarnings ("JavaDoc")
     public void createArchive( MavenProject project, MavenArchiveConfiguration archiveConfiguration )
         throws ArchiverException, ManifestException, IOException, DependencyResolutionRequiredException
     {
@@ -497,8 +503,16 @@ public class MavenArchiver
     {
         // we have to clone the project instance so we can write out the pom with the deployment version,
         // without impacting the main project instance...
-        // TODO use clone() in Maven 2.0.9+
-        MavenProject workingProject = new MavenProject( project );
+        MavenProject workingProject = null;
+        try
+        {
+            workingProject = (MavenProject) project.clone();
+        }
+        catch (CloneNotSupportedException e)
+        {
+            // Should never happen
+            throw new ArchiverException( "Failed to clone Maven project", e );
+        }
 
         boolean forced = archiveConfiguration.isForced();
         if ( archiveConfiguration.isAddMavenDescriptor() )
@@ -556,6 +570,8 @@ public class MavenArchiver
 
         archiver.setCompress( archiveConfiguration.isCompress() );
 
+        archiver.setRecompressAddedZips( archiveConfiguration.isRecompressAddedZips() );
+
         archiver.setIndex( archiveConfiguration.isIndex() );
 
         archiver.setDestFile( archiveFile );
@@ -563,7 +579,7 @@ public class MavenArchiver
         // make the archiver index the jars on the classpath, if we are adding that to the manifest
         if ( archiveConfiguration.getManifest().isAddClasspath() )
         {
-            @SuppressWarnings( "unchecked" ) List<String> artifacts = project.getRuntimeClasspathElements();
+            @SuppressWarnings ("unchecked") List<String> artifacts = project.getRuntimeClasspathElements();
             for ( String artifact : artifacts )
             {
                 File f = new File( artifact );
@@ -582,7 +598,7 @@ public class MavenArchiver
         archiver.createArchive();
     }
 
-    private void addCreatedByEntry( MavenSession session, Manifest m, Map entries )
+    private void addCreatedByEntry( MavenSession session, Manifest m, Map<String, String> entries )
         throws ManifestException
     {
         String createdBy = "Apache Maven";
